#!/bin/bash

[[ -f /proc/device-tree/compatible ]] && DT_COMPAT_LIST=`tr < /proc/device-tree/compatible  '\000' '\n'`

    for compat in $DT_COMPAT_LIST; do
        case "$compat" in
            "onion,omega2p" )
                INSPARK_HW_VERSION=SmartMetrix;
                break;
            ;;
            "mub" )
                INSPARK_HW_VERSION=milandr;
                break;
            ;;

        esac
    done;


case "$INSPARK_HW_VERSION" in
  "SmartMetrix" )
	## Generate UID based on device's MAC addr for ra0 intf

	. /lib/ramips.sh
	board=$(ramips_board_name)

	generateMacUid () {
        	# grab line 2 of iwpriv output
        	line1=$(iwpriv ra0 e2p | sed -n '2p')
        	# isolate bytes at addresses 0x0004 and 0x0006, and perform byte swap
        	bytes5432=$(echo $line1 |  awk '{print $3":"$4}' | \
        	awk -F ":" \
        	'{print substr($2,3) substr($2,1,2) substr($4,3) substr($4,1,2)}')

        	# grab line 3 of iwpriv output
        	line2=$(iwpriv ra0 e2p | sed -n '3p')
        	# isolate bytes at address 0x0008 and perform byte swap
        	bytes10=$(echo $line2 | awk '{print $1}' | \
        	awk -F ":" '{print substr($2,3) substr($2,1,2)}')

        macId=$(echo ${bytes5432}${bytes10})
        echo $macId
	}

	while [ ${#uid} != 12 ]
	do
		uid=$(generateMacUid)
	sleep 1
	done

	echo $uid > /var/inspark/vsn
	echo "Unique ID based on MACD for this device is: $uid"

	## Set hostname
	uci -q batch <<-EOF > /dev/null
        	set system.@system[0].hostname=Omega-$uid
       		set system.@led[0].sysfs="$board:amber:system"
        	set system.@led[0].trigger='default-on'
        	commit system
        	set wireless.@wifi-iface[0].ssid='Omega-$uid'
       		set wireless.sta.led='${board}:blue:wifi'
        	commit wireless
	EOF

	echo $(uci get system.@system[0].hostname) > /proc/sys/kernel/hostname
	sed -i "s/HOSTNAME/$uid/g" /etc/incrontabs/root > /dev/null 2>/dev/null

   ;;

    * )
    ;;
esac

